diff --git a/app_button - ORG.c b/app_button.c
index 9cc9000..1c6e4f5 100644
--- a/app_button - ORG.c	
+++ b/app_button.c
@@ -52,8 +52,8 @@ static uint32_t                       m_detection_delay;           /**< Delay be
 APP_TIMER_DEF(m_detection_delay_timer_id);  /**< Polling timer id. */
 
 
-static uint32_t m_pin_state;
-static uint32_t m_pin_transition;
+static uint64_t m_pin_state;
+static uint64_t m_pin_transition;
 
 /**@brief Function for handling the timeout that delays reporting buttons as pushed.
  *
@@ -75,12 +75,12 @@ static void detection_delay_timeout_handler(void * p_context)
     for (i = 0; i < m_button_count; i++)
     {
         app_button_cfg_t const * p_btn = &mp_buttons[i];
-        uint32_t btn_mask = 1 << p_btn->pin_no;
+        uint64_t btn_mask = 1ULL << p_btn->pin_no;
         if (btn_mask & m_pin_transition)
         {
             m_pin_transition &= ~btn_mask;
             bool pin_is_set = nrf_drv_gpiote_in_is_set(p_btn->pin_no);
-            if ((m_pin_state & (1 << p_btn->pin_no)) == (pin_is_set << p_btn->pin_no))
+            if ((m_pin_state & (1ULL << p_btn->pin_no)) == (((uint64_t)pin_is_set) << p_btn->pin_no))
             {
                 uint32_t transition = !(pin_is_set ^ (p_btn->active_state == APP_BUTTON_ACTIVE_HIGH));
 
@@ -96,7 +96,7 @@ static void detection_delay_timeout_handler(void * p_context)
 static void gpiote_event_handler(nrf_drv_gpiote_pin_t pin, nrf_gpiote_polarity_t action)
 {
     uint32_t err_code;
-    uint32_t pin_mask = 1 << pin;
+    uint64_t pin_mask = 1ULL << pin;
 
     // Start detection timer. If timer is already running, the detection period is restarted.
     // NOTE: Using the p_context parameter of app_timer_start() to transfer the pin states to the
@@ -164,7 +164,11 @@ uint32_t app_button_init(app_button_cfg_t const *       p_buttons,
     {
         app_button_cfg_t const * p_btn = &p_buttons[button_count];
 
+#if defined(BUTTON_HIGH_ACCURACY_ENABLED) && (BUTTON_HIGH_ACCURACY_ENABLED == 1)
+        nrf_drv_gpiote_in_config_t config = GPIOTE_CONFIG_IN_SENSE_TOGGLE(p_btn->hi_accuracy);
+#else
         nrf_drv_gpiote_in_config_t config = GPIOTE_CONFIG_IN_SENSE_TOGGLE(false);
+#endif
         config.pull = p_btn->pull_cfg;
 
         err_code = nrf_drv_gpiote_in_init(p_btn->pin_no, &config, gpiote_event_handler);
